@@ -1,23 +1,24 @@
 #![allow(clippy::integer_arithmetic)]
-use log::*;
-use serde::{Deserialize, Serialize};
-use solana_sdk::{
-    clock::{Slot, UnixTimestamp},
-    deserialize_utils::default_on_eof,
-    pubkey::Pubkey,
-    signature::Signature,
-    sysvar::is_sysvar_id,
-    transaction::{Transaction, TransactionError},
+use {
+    log::*,
+    serde::{Deserialize, Serialize},
+    solana_sdk::{
+        clock::{Slot, UnixTimestamp},
+        deserialize_utils::default_on_eof,
+        pubkey::Pubkey,
+        signature::Signature,
+        sysvar::is_sysvar_id,
+        transaction::{Transaction, TransactionError},
+    },
+    solana_storage_proto::convert::{generated, tx_by_addr},
+    solana_transaction_status::{
+        ConfirmedBlock, ConfirmedTransaction, ConfirmedTransactionStatusWithSignature, Reward,
+        TransactionByAddrInfo, TransactionConfirmationStatus, TransactionStatus,
+        TransactionStatusMeta, TransactionWithStatusMeta,
+    },
+    std::{collections::HashMap, convert::TryInto},
+    thiserror::Error,
 };
-use solana_storage_proto::convert::generated;
-use solana_storage_proto::convert::tx_by_addr;
-use solana_transaction_status::{
-    ConfirmedBlock, ConfirmedTransaction, ConfirmedTransactionStatusWithSignature, Reward,
-    TransactionByAddrInfo, TransactionConfirmationStatus, TransactionStatus, TransactionStatusMeta,
-    TransactionWithStatusMeta,
-};
-use std::{collections::HashMap, convert::TryInto};
-use thiserror::Error;
 
 #[macro_use]
 extern crate serde_derive;
@@ -237,6 +238,7 @@ impl From<StoredConfirmedBlockReward> for Reward {
             lamports,
             post_balance: 0,
             reward_type: None,
+            commission: None,
         }
     }
 }
